Stan Math Library: stan/math/rev/mat/fun Directory Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

fun Directory Reference

## Files
file | cholesky_decompose.hpp [code]
file | columns_dot_product.hpp [code]
file | columns_dot_self.hpp [code]
file | crossprod.hpp [code]
file | determinant.hpp [code]
file | divide.hpp [code]
file | dot_product.hpp [code]
file | dot_self.hpp [code]
file | Eigen_NumTraits.hpp [code]
file | grad.hpp [code]
file | initialize_variable.hpp [code]
file | LDLT_alloc.hpp [code]
file | LDLT_factor.hpp [code]
file | log_determinant.hpp [code]
file | log_determinant_ldlt.hpp [code]
file | log_determinant_spd.hpp [code]
file | log_softmax.hpp [code]
file | log_sum_exp.hpp [code]
file | mdivide_left.hpp [code]
file | mdivide_left_ldlt.hpp [code]
file | mdivide_left_spd.hpp [code]
file | mdivide_left_tri.hpp [code]
file | multiply.hpp [code]
file | multiply_lower_tri_self_transpose.hpp [code]
file | quad_form.hpp [code]
file | quad_form_sym.hpp [code]
file | rows_dot_product.hpp [code]
file | sd.hpp [code]
file | softmax.hpp [code]
file | sort_asc.hpp [code]
file | sort_desc.hpp [code]
file | squared_distance.hpp [code]
file | stan_print.hpp [code]
file | sum.hpp [code]
file | tcrossprod.hpp [code]
file | to_var.hpp [code]
file | trace_gen_inv_quad_form_ldlt.hpp [code]
file | trace_gen_quad_form.hpp [code]
file | trace_inv_quad_form_ldlt.hpp [code]
file | trace_quad_form.hpp [code]
file | typedefs.hpp [code]
file | unit_vector_constrain.hpp [code]
file | variance.hpp [code]

[ Stan Home Page ] © 2011–2016, Stan Development Team.